/***********************************************************************************************************************************************
Program Name: call-design_biomAR.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
     ** This program provides an example call to the %design_biomAR SAS macro;
     ** See the macro header file for a complete list of the macro parameters;

**** Reference Paper:
      Barry, William T., et al. "The use of Bayesian hierarchical models for adaptive randomization in biomarker-driven phase II studies." 
         Journal of biopharmaceutical statistics 25.1 (2015): 66-88. 

***********************************************************************************************************************************************/

ods html close;
ods listing close;
proc datasets library=work noprint kill; run; quit;

%let macroPath = C:\Users\psioda\Documents\Stat-Projects\AR-biomarker\kd-programs\macro;
%let resultPath =C:\Users\psioda\Documents\Stat-Projects\AR-biomarker\kd-programs\output;

libname s "&resultPath.";
%include "&macroPath.\design_biomAR.sas";


%design_biomAR(
    seed1 = 1353153,
    seed2 = 2315351,

    Nmax   =  40,
    Nmin   =  40,       
    numSimStudies = 10,

    Nstart =   1,

    J0     =   2,
    K0     =   2,

    prevBiom   = { 0.50 0.50 },
    pi_True    = %str({ 0.25 0.25, 0.25 0.50 }),
    pi1_Target = 0.50,
    pi0_Target = 0.25,

    mappingMethod = 1,
    priorType     = phi_rand_BAL,

    deltaU =  0.900,
    deltaL =  0.000, 

    nbi   =  500,
    nmc   = 5000,
    nthin =    1

);


